@@ -28,9 +28,7 @@ static int WinOffsetNormal[5]   = {139, 140, 141, 142, 143};
 FilterLatex::FilterLatex(FILE *filein, FILE *fileout, int latexflag)
     : FilterX (filein,fileout)
 {
-	strcpy(wordBreakStr,"{\\wbr}");
-	prefixStr[0]='\0';
-	suffixStr[0]='\0';
+	wordBreakStr = "{\\wbr}";
 	buffer[0]='\0';
 	verbatim=false; // Is in verbatim mode??
 	latexFlag=latexflag;	
@@ -46,7 +44,7 @@ FilterLatex::~FilterLatex()
 bool FilterLatex::GetNextToken(char * token, bool * thaiFlag)
 {
 char *curPtr;
-char *stPtr, tmpch;
+char *stPtr;
 char *stVer;
 
 	if (buffer[0]=='\0') 
@@ -57,17 +55,16 @@ char *stVer;
 	*token='\0';
 	if (verbatim) {
 		*thaiFlag=false;
-		if ((stVer=strstr(buffer,"\\end{verbatim}"))==NULL){
+		stVer=strstr(buffer,"\\end{verbatim}");
+		if (stVer==NULL){
 			strcpy(token,buffer);
 			buffer[0]='\0';
 			return true;
 		}else{
 			stVer+=strlen("\\end{verbatim}");
-			tmpch=*stVer;
-			*stVer=0;
-			strcpy(token,buffer);
-			*stVer=tmpch;
-			strcpy(buffer,stVer);
+			strncpy(token,buffer,stVer-buffer);
+			token[stVer-buffer]='\0';
+			memmove(buffer,stVer,strlen(stVer)+1);
 			verbatim=false;
 			return true;
 		}
@@ -75,18 +72,17 @@ char *stVer;
 
 	while (isPunc(*curPtr))
 		curPtr++;
-	*thaiFlag=(*curPtr & 0x80)? true:false;
+	*thaiFlag=isThai(*curPtr);
 	curPtr++;
 	if (*thaiFlag){
 		for(;;){ //for finding thai line + thailine +...+ thailine
-			while (*curPtr & 0x80) {  //isPunc(*curPtr);
+			while (isThai(*curPtr)) {  //isPunc(*curPtr);
 				curPtr++;
 			}
-			if ((*curPtr!=0)&&(*curPtr!='\n')){
-				tmpch=*curPtr;
-				*curPtr=0;
-				strcat(token,stPtr);
-				*curPtr=tmpch;
+			if (*curPtr!=0 && *curPtr!='\n'){
+				int prevLen=strlen(token);
+				strncat(token,stPtr,curPtr-stPtr);
+				token[prevLen+(curPtr-stPtr)]='\0';
 				//store new buffer
 				memmove(buffer,curPtr,strlen(curPtr)+1);
 				return true;
@@ -103,7 +99,7 @@ char *stVer;
 				}
 				curPtr=buffer;
 #ifdef CAT_THAI_LINES
-				if (*curPtr>0) //not thai character
+				if (!isThai(*curPtr)) //not thai character
 #endif
 				{
 					strcat(token,"\n");
@@ -112,14 +108,12 @@ char *stVer;
 			}
 		}
 	}else{
-		while ((*curPtr>0) || (isPunc(*curPtr)) || (isSpace(*curPtr)) ){
+		while (*curPtr && !isThai(*curPtr)){
 			curPtr++;
 		}
 		if (*curPtr!=0){
-			tmpch=*curPtr;
-			*curPtr=0;
-			strcpy(token,stPtr);
-			*curPtr=tmpch;
+			strncpy(token,stPtr,curPtr-stPtr);
+			token[curPtr-stPtr]='\0';
 			//store new buffer
 			memmove(buffer,curPtr,strlen(curPtr)+1);
 		}else{
