@@ -32,22 +32,8 @@ FilterX::~FilterX()
 	fflush(fpout);
 }
 
-bool FilterX::GetWordBreak(char *wbr)
+const char* FilterX::GetWordBreak()
 {
-	strcpy(wbr,wordBreakStr);
-	return true;
+	return wordBreakStr;
 }
 
-bool FilterX::GetPrefix(char *preStr)
-{
-	strcpy(preStr,prefixStr);
-	return true;
-}
-
-bool FilterX::GetSuffix(char *suffStr)
-{
-	strcpy(suffStr,suffixStr);
-	return true;
-}
-
-
