@@ -14,25 +14,12 @@
 MaxWordSeg::MaxWordSeg():AbsWordSeg()
 {
 	noAmbArea=0;
-	MyDict=trie_new_from_file("swathdic.tri");
 	score = new short int[MAXSEP];
 }
 
-MaxWordSeg::MaxWordSeg(const char *dataPath):AbsWordSeg()
-{
-	char *triePath=new char[strlen(dataPath)+30];
-	sprintf(triePath,"%s/swathdic.tri",dataPath);
-	MyDict=trie_new_from_file(triePath);
-	delete[] triePath;
-	noAmbArea=0;
-	score = new short int[MAXSEP];
-}
-
-
 MaxWordSeg::~MaxWordSeg()
 {
 	delete[] score;
-	trie_free(MyDict);
 }
 
 
@@ -107,7 +94,7 @@ short int senIdx=0,bestSenIdx=0,prevSenIdx=0,tmps; //tmps save score.
 short int sepIdx=0,Idx=0,tmpidx;
 short int nextSepIdx=0,curState;
 short int scoreidx;
-wordStateType wState;
+wordState wState;
 short int bestScore=0;
 bool foundUnk;
 bool stopCreate;
