@@ -7,10 +7,14 @@
 #define MAXSEP 500   // maximun of seperation points (maximun words in a sentences)
 #define MAXTAG 47     // number of all posible POSs.
 
-typedef struct wordStateDef {
+struct wordState {
 	int backState;
 	unsigned char branchState;
-} wordStateType;
+
+	wordState () {}
+	wordState (int backState, unsigned char branchState)
+		: backState (backState), branchState (branchState) {}
+};
 
 typedef struct wt_detail_def {
   char tag_no;
@@ -32,8 +36,26 @@ typedef struct SepTypeDef {
    short int Sep[MAXSEP];
 } SepType;
 
-bool isSpace(char ch);
-bool isHex(char ch);
-bool isPunc(char ch);
+inline bool isSpace(char ch)
+{
+	return (ch==' ') || ('\t'<=ch && ch<='\r');
+}
+
+inline bool isHex(char ch)
+{
+	return ('0'<=ch && ch<='9') || ('a'<=ch && ch<='f');
+}
+
+inline bool isPunc(char ch)
+{
+//	if (  ((ch>=33)&&(ch<=47)) || ((ch>=58)&&(ch<=63))
+//		      || ((ch>=91)&&(ch<=96))  )
+	return ch=='\'' || ch=='"' || ch=='`' || ch=='.';
+}
+
+inline bool isThai(char ch)
+{
+	return ch & 0x80;
+}
 
 #endif
